### Maintainer
Ted Johnson (UNLV, NASA GSFC, SURA)

### Authors
Cameron Kelahan (NASA GSFC, SURA)  
Ted Johnson (UNLV, NASA GSFC, SURA)

### Contributers
Tobi Hammond (NASA GSFC, SURA)

### Primary Advisor
Avi Mandell (NASA GSFC)

### Exo-PSG Team
Geronimo Villanueva (NASA GSFC)
Avi Mandell (NASA GSFC)
Vincent Kofman (NASA GSFC, AU)  
Sara Faggi (NASA GSFC, AU)  
Natasha Latouf (NASA GSFC, GMU)  
Michael Himes (NASA GSFC)
Eleonora Alei (NASA GSFC)
Tyler Baines (NASA GSFC, SURA)
Ashraf Dhahbi (NASA GSFC, SURA)
Ally Payne (NASA GSFC, SURA)
Tobi Hammond (NASA GSFC, SURA)

### Based on SPOTTY
Tom Barclay (NASA GSFC, UMBC)  
Veselin Kostov (NASA GSFC, UMCP)

### Custom PHOENIX Model Spectra
Peter Hauschildt (University of Hamburg)
